@@ -274,6 +274,8 @@ struct lldpd_port {
 	int			 p_descr_force; /* Description has been forced by user */
 	u_int16_t		 p_mfs;
 	u_int16_t		 p_ttl; /* TTL for remote port */
+	int			 p_vlan_tx_tag;
+	int			 p_vlan_tx_enabled;
 
 #ifdef ENABLE_DOT3
 	/* Dot3 stuff */
@@ -341,6 +343,8 @@ struct lldpd_port_set {
 	char *local_id;
 	char *local_descr;
 	int rxtx;
+	int vlan_tx_tag;
+	int vlan_tx_enabled;
 #ifdef ENABLE_LLDPMED
 	struct lldpd_med_policy *med_policy;
 	struct lldpd_med_loc    *med_location;
